@@ -18,6 +18,7 @@ public:
     Q_ENUM(Role)
 
     explicit NoteBooksModel(QObject *parent = nullptr);
+    NoteBooksModel(const QString &directory, QObject *parent = nullptr);
 
     int rowCount(const QModelIndex &index) const override;
 
@@ -25,13 +26,18 @@ public:
 
     QHash<int, QByteArray> roleNames() const override;
 
-    Q_INVOKABLE void addNoteBook(const QString &name, const QString &icon, const QString &color);
+    Q_INVOKABLE QString addNoteBook(const QString &name, const QString &icon, const QString &color);
+    Q_INVOKABLE void editNoteBook(const QString &path, const QString &name, const QString &icon, const QString &color);
+    Q_INVOKABLE void deleteNoteBook(const QString &path);
 
-    Q_INVOKABLE void deleteNoteBook(const QString &name);
+    Q_INVOKABLE QString iconNameForPath(const QString &path) const;
+    Q_INVOKABLE QString colorForPath(const QString &path) const;
 
-    Q_INVOKABLE void renameNoteBook(const QUrl &path, const QString &name);
+Q_SIGNALS:
+    void noteBookRenamed(const QString &oldName, const QString &newName, const QString &path);
 
 private:
+    QModelIndex indexForPath(const QString &path) const;
     QDir directory;
 };
 
